import { ComponentTester } from './component-tester';
import { RouterTestingHarness } from '@angular/router/testing';
import { UrlTree } from '@angular/router';
/**
 * A thin wrapper around Angular RouterTestingHarness which helps testing routed components.
 * It allows, based on a configured testing module where the router is provided, to initially navigate
 * to a given route, then test the routed component. It's then possible to either navigate again with
 * the wrapped harness, or to use the component to trigger navigation, and test that the URL has changed
 * for example.
 */
export declare class RoutingTester extends ComponentTester<unknown> {
    readonly harness: RouterTestingHarness;
    constructor(harness: RouterTestingHarness);
    /**
     * Creates a RouterTestngHarness and uses it to navigate to the given URL
     * @param url the URL to initially navigate to.
     * @return a promise which resolves to a RoutingTester which wraps the harness
     * and its fixture.
     */
    static forUrl(url: string): Promise<RoutingTester>;
    /**
     * Gets the current URL of the Router service as a string
     */
    get url(): string;
    /**
     * Gets the current URL of the Router service as an UrlTree, to be able to test its
     * elements (query params, etc.)
     */
    get urlTree(): UrlTree;
}
